@@ -1172,13 +1172,12 @@ egg_desktop_file_launchv (EggDesktopFile *desktop_file,
 
   if (screen)
     {
-      char *display_name = gdk_screen_make_display_name (screen);
+      display = gdk_screen_get_display (screen);
+      char *display_name = g_strdup (gdk_display_get_name (display));
       char *display_env = g_strdup_printf ("DISPLAY=%s", display_name);
       env = array_putenv (env, display_env);
       g_free (display_name);
       g_free (display_env);
-
-      display = gdk_screen_get_display (screen);
     }
   else
     {
