@@ -31,7 +31,7 @@
 #include <config.h>
 #endif
 
-#include <libintl.h>
+#include <glib/gi18n-lib.h>
 #include <stdlib.h>
 #include <string.h>
 
